@@ -1,4 +1,4 @@
-"""Page CMS functions related to the request object."""
+"""Page CMS functions related to the ``request`` object."""
 from django.core.handlers.base import BaseHandler
 from django.core.handlers.wsgi import WSGIRequest
 from django.http import HttpResponse, HttpResponseRedirect
@@ -8,7 +8,7 @@ from django.core.urlresolvers import reverse
 from pages import settings
 
 def get_request_mock():
-    """Build a request mock that can be used for testing."""
+    """Build a ``request`` mock that can be used for testing."""
     bh = BaseHandler()
     bh.load_middleware()
     request = WSGIRequest({
@@ -26,8 +26,8 @@ def get_request_mock():
     return request
 
 class AutoRenderHttpError(Exception):
-    """Cannot return context dictionary because a view returned an HTTP
-    response when a (template_name, context) tuple was expected."""
+    """Cannot return context dictionary because a view returned an
+    ``HttpResponse`` when a (template_name, context) tuple was expected."""
     pass
 
 def auto_render(func):
@@ -55,7 +55,7 @@ def auto_render(func):
                             context_instance=RequestContext(request))
     return _dec
 
-def get_slug_and_relative_path(path):
+def get_slug_and_relative_path(path, lang=None):
     """Return the page's slug and relative path."""
     root = reverse('pages-root')
     if path.startswith(root):
@@ -63,7 +63,6 @@ def get_slug_and_relative_path(path):
     if len(path) and path[-1] == '/':
         path = path[:-1]
     slug = path.split("/")[-1]
-    lang = None
     if settings.PAGE_USE_LANGUAGE_PREFIX:
         lang = path.split("/")[0]
         path = path[(len(lang) + 1):]
