@@ -22,10 +22,13 @@ $(function() {
     
     // Set the publication status
     var select = $('#id_status');
-    var opt = ({ 0: 'draft', 1: 'published', 3: 'hidden' })[select.val()];
-    var img = $('<img src="/media/pages/images/icons/'+opt+'.gif" alt="'+opt+'" />').insertAfter(select);
+    var opt = ({ 0: 'draft', 1: 'published', 2: 'expired', 3: 'hidden' })[select.val()];
+    var img = $('<img src="'+page_media_url+'/images/icons/'+opt+'.gif" alt="'+opt+'" />').insertAfter(select);
+    // disable ajax post if page not already created (add view)
+    var change_status = (typeof(add_form) !== 'undefined' && add_form) ? 0 : 1;
+
     select.change(function(e) {
-        pages.update_published_icon('', select, img);
+        pages.update_published_icon('', select, img, change_status);
     });
     
     // Translation helper
@@ -40,18 +43,6 @@ $(function() {
         }
     });
     
-    // Select the appropriate template option
-    // This code should go away soon
-    /*var template = $.query.get('template');
-    if (template) {
-        $('#id_template option').each(function() {
-            if (template == this.value) {
-                $(this).attr('selected', true);
-                return false;
-            };
-        });
-    };*/
-    
     // Confirm language and template change if page is not saved
     // this code doesn't work with languages
     $.each(['language', 'template'], function(i, label) {
@@ -59,13 +50,16 @@ $(function() {
         if (select.length) {
             var orig_ = select.val();
             select.change(function() {
-                if(confirm(gettext('You will loose any changes you have done to the page. Are you sure?')))
+                if(confirm(gettext('You may lose any changes you have done to the page. Are you sure?')))
                     $('input[name=_continue]').click();
             });
         };
     });
     
     // Disable the page content if the page is a redirection
+    /*
+    // To fix if we use placeholder in templates for META or extra content
+    
     var redirect = $('#id_redirect_to').change(update_redirect);
     var affected = $('.form-row:has(#id_language), .form-row:has(#id_template), .module-content .form-row')
         .css('position', 'relative');
@@ -84,6 +78,7 @@ $(function() {
         redirect.val() ? overlay.show() : overlay.hide();
     }
     update_redirect();
+    */
     
     // Content revision selector
     $('.revisions').change(function () {
@@ -119,4 +114,8 @@ $(function() {
         }
         return false;
     });
+    
+    $('.js-confirm-delete').click(function() {
+        return confirm(gettext('Are you sure you want to delete this content?'));
+    });
 });
